@@ -8,4 +8,7 @@ register = template.Library()
 @register.inclusion_tag("lizard_ui/tag_login.html",
                         takes_context=True)
 def display_login(context):
-    return {'user': context['user']}
+    result = {'user': context['user']}
+    if 'next' in context:
+        result.update({'next': context['next']})
+    return result
